@@ -21,7 +21,9 @@ from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
 
 class DockerError(Exception):
-    pass
+    def __init__(self, cli_message, server_message):
+        self.cli_message = cli_message
+        self.server_message = server_message
 
 class S3Error(Exception):
     pass
@@ -39,6 +41,8 @@ class Utils(object):
 	min_docker_version = 18.03
 	# if a scanner for an app id is executed too close in time, skencli must wait for 5 minutes
 	etl_waiting_threshold = 300
+	# docker container exit code 137: Indicates failure as container received SIGKILL
+	container_exit_code_kill = 137
 
 	@classmethod
 	def get_retryable_http(cls):
@@ -249,7 +253,7 @@ class Utils(object):
 		try:
 			client = cls.docker_login(scan_info)
 			cls.docker_pull_image(client, cls.cloc_image)
-			command_line = "/scan --json --out /scan/sken-cloc.json  --exclude-dir node_modules,target,dist,build,node --skip-archive '(zip|tar|jar|war(.(gz|Z|bz2|xz|7z))?)' --exclude-ext json,xml,svg,md"
+			command_line = "/scan --json --out /scan/sken-cloc.json  --exclude-dir node_modules,target,dist,build,node,.git,.hg --skip-archive '(zip|tar|jar|war(.(gz|Z|bz2|xz|7z))?)' --exclude-ext json,xml,svg,md"
 			container = client.containers.run(cls.cloc_image, command_line, volumes={build_dir: {
 				'bind': '/scan', 'mode': 'rw'}}, detach=True, tty=False, stdout=True, stderr=True)
 			container.wait()
